==> confpiler-0.2.1.crate: confpiler-0.2.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.2.1 (2022-04-11)

<csr-id-598449234c43b8ef010c7d738086a7a7908fd3ea/>
<csr-id-10476962e0dd2d8220d9c916d69ac98513744700/>

### Chore

 - <csr-id-8b4d0bf65e14f1f213674d717755fe94fe51a2f8/> add changelogs

### Documentation

 - <csr-id-236de63e40891b03c7b358827f1a8de670659a89/> update cargo tomls with relevant info
 - <csr-id-97b942cc898b34b8888ce1c099ad9429b297f6cc/> fixing typos, making clarifications
 - <csr-id-a683f0db860635a5cfb5917b6efd45e5e54653ca/> more tests, better readme

### New Features

 - <csr-id-9781899d3b3101eef91af431befa964c65bf87be/> allow specifying a prefix for generated keys
   This adds .with_prefix to the builder and --prefix to the CLI
 - <csr-id-10602d0361fc6e76a084021136fb0664d9897158/> first pass as cli tool
   a bunch of files were added, but they're mainly to support the
   integration tests
 - <csr-id-72375f349bb71c2bba47e23189d54f64e0a84d73/> initial commit

### Bug Fixes

 - <csr-id-bd1f06342a6fdd3cacd01854bfc0176b697a7359/> working basic example

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 10 commits contributed to the release over the course of 45 calendar days.
 - 10 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - add changelogs ([`8b4d0bf`](https://github.comgit//mattcl/confpiler/commit/8b4d0bf65e14f1f213674d717755fe94fe51a2f8))
    - clippy suggestions ([`5984492`](https://github.comgit//mattcl/confpiler/commit/598449234c43b8ef010c7d738086a7a7908fd3ea))
    - cargo fmt ([`1047696`](https://github.comgit//mattcl/confpiler/commit/10476962e0dd2d8220d9c916d69ac98513744700))
    - allow specifying a prefix for generated keys ([`9781899`](https://github.comgit//mattcl/confpiler/commit/9781899d3b3101eef91af431befa964c65bf87be))
    - working basic example ([`bd1f063`](https://github.comgit//mattcl/confpiler/commit/bd1f06342a6fdd3cacd01854bfc0176b697a7359))
    - update cargo tomls with relevant info ([`236de63`](https://github.comgit//mattcl/confpiler/commit/236de63e40891b03c7b358827f1a8de670659a89))
    - fixing typos, making clarifications ([`97b942c`](https://github.comgit//mattcl/confpiler/commit/97b942cc898b34b8888ce1c099ad9429b297f6cc))
    - more tests, better readme ([`a683f0d`](https://github.comgit//mattcl/confpiler/commit/a683f0db860635a5cfb5917b6efd45e5e54653ca))
    - first pass as cli tool ([`10602d0`](https://github.comgit//mattcl/confpiler/commit/10602d0361fc6e76a084021136fb0664d9897158))
    - initial commit ([`72375f3`](https://github.comgit//mattcl/confpiler/commit/72375f349bb71c2bba47e23189d54f64e0a84d73))
</details>

==> confpiler-0.2.2.crate: confpiler-0.2.2/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.2.2 (2022-04-21)

### Chore

 - <csr-id-c51a85f54f8798f0cd09204d8f361ce730440956/> specify min rust version

### Documentation

 - <csr-id-111094b489086f00c81e4c7c4bc6430b84f25a36/> Remove hobby project disclaimer.
   This will be more regularly maintained

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 2 commits contributed to the release over the course of 9 calendar days.
 - 10 days passed between releases.
 - 2 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - specify min rust version ([`c51a85f`](https://github.comgit//mattcl/confpiler/commit/c51a85f54f8798f0cd09204d8f361ce730440956))
    - Remove hobby project disclaimer. ([`111094b`](https://github.comgit//mattcl/confpiler/commit/111094b489086f00c81e4c7c4bc6430b84f25a36))
</details>

## 0.2.1 (2022-04-11)

<csr-id-598449234c43b8ef010c7d738086a7a7908fd3ea/>
<csr-id-10476962e0dd2d8220d9c916d69ac98513744700/>
<csr-id-8b4d0bf65e14f1f213674d717755fe94fe51a2f8/>

### Chore

 - <csr-id-8b4d0bf65e14f1f213674d717755fe94fe51a2f8/> add changelogs

### Documentation

 - <csr-id-236de63e40891b03c7b358827f1a8de670659a89/> update cargo tomls with relevant info
 - <csr-id-97b942cc898b34b8888ce1c099ad9429b297f6cc/> fixing typos, making clarifications
 - <csr-id-a683f0db860635a5cfb5917b6efd45e5e54653ca/> more tests, better readme

### New Features

 - <csr-id-9781899d3b3101eef91af431befa964c65bf87be/> allow specifying a prefix for generated keys
   This adds .with_prefix to the builder and --prefix to the CLI
 - <csr-id-10602d0361fc6e76a084021136fb0664d9897158/> first pass as cli tool
   a bunch of files were added, but they're mainly to support the
   integration tests
 - <csr-id-72375f349bb71c2bba47e23189d54f64e0a84d73/> initial commit

### Bug Fixes

 - <csr-id-bd1f06342a6fdd3cacd01854bfc0176b697a7359/> working basic example

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 11 commits contributed to the release over the course of 45 calendar days.
 - 10 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release confpiler v0.2.1, confpiler_cli v0.3.1 ([`e781460`](https://github.comgit//mattcl/confpiler/commit/e78146059e9b97f324dba3806edd2d2ab5a61e10))
    - add changelogs ([`8b4d0bf`](https://github.comgit//mattcl/confpiler/commit/8b4d0bf65e14f1f213674d717755fe94fe51a2f8))
    - clippy suggestions ([`5984492`](https://github.comgit//mattcl/confpiler/commit/598449234c43b8ef010c7d738086a7a7908fd3ea))
    - cargo fmt ([`1047696`](https://github.comgit//mattcl/confpiler/commit/10476962e0dd2d8220d9c916d69ac98513744700))
    - allow specifying a prefix for generated keys ([`9781899`](https://github.comgit//mattcl/confpiler/commit/9781899d3b3101eef91af431befa964c65bf87be))
    - working basic example ([`bd1f063`](https://github.comgit//mattcl/confpiler/commit/bd1f06342a6fdd3cacd01854bfc0176b697a7359))
    - update cargo tomls with relevant info ([`236de63`](https://github.comgit//mattcl/confpiler/commit/236de63e40891b03c7b358827f1a8de670659a89))
    - fixing typos, making clarifications ([`97b942c`](https://github.comgit//mattcl/confpiler/commit/97b942cc898b34b8888ce1c099ad9429b297f6cc))
    - more tests, better readme ([`a683f0d`](https://github.comgit//mattcl/confpiler/commit/a683f0db860635a5cfb5917b6efd45e5e54653ca))
    - first pass as cli tool ([`10602d0`](https://github.comgit//mattcl/confpiler/commit/10602d0361fc6e76a084021136fb0664d9897158))
    - initial commit ([`72375f3`](https://github.comgit//mattcl/confpiler/commit/72375f349bb71c2bba47e23189d54f64e0a84d73))
</details>
